@@ -128,12 +128,19 @@ def ask_questions(config, defaults):
         config,
         defaults,
     )
+    if config["ACTIVATE_HTTPS"]:
+        ask_bool(
+            ("You are using local machine without static IP"),
+            "ACTIVATE_LOCAL_CERTS",
+            config,
+            defaults,
+        )
     ask_bool(
-        ("You are using local machine without static IP"),
-        "ACTIVATE_LOCAL_CERTS",
-        config,
-        defaults,
-    )
+            ("Enable Development Mode"),
+            "DEV_MODE",
+            config,
+            defaults,
+        )
     ask("Wildcard domain for local platform", "WILDCARD_DOMAIN", config, defaults)
 
 
