@@ -106,6 +106,20 @@ def import_demo_course(runner):
     runner.run("cms", "hooks", "cms", "importdemocourse")
 
 
+def delete_course(course_id):
+    command = BASE_OPENEDX_COMMAND + """
+        ./manage.py cms delete_course {course_id}
+    """
+    return command.format(course_id=course_id)
+
+
+def listcourses():
+    command = BASE_OPENEDX_COMMAND + """
+        ./manage.py cms dump_course_ids 
+    """
+    return command
+  
+
 def set_theme(theme_name, domain_name, runner):
     command = BASE_OPENEDX_COMMAND
     command += """
