@@ -9,9 +9,7 @@ ALLOWED_HOSTS = [
     ENV_TOKENS.get("LMS_BASE"),
     FEATURES["PREVIEW_LMS_BASE"],
     "lms",
-    "127.0.0.1",
-    "localhost",
-    "preview.localhost",
+    "127.0.0.1"
 ]
 
 # Required to display all courses on start page
